@@ -6,7 +6,7 @@ App::git::ship - Git command for shipping your project
 
 =head1 VERSION
 
-0.03
+0.04
 
 =head1 DESCRIPTION
 
@@ -46,6 +46,17 @@ standard rules instead of enforcing more rules.
 
   1;
 
+=head1 Git aliases
+
+These are some ideas for aliases which could be useful when working with
+C<git-ship>.
+
+  $ cat $HOME/.gitconfig
+  [alias]
+    build = ship build
+    cl = ship clean
+    start = ship init
+
 =head1 TODO
 
 This project is currently in the EXPERIMENTAL phase, where I'm testing things
@@ -59,8 +70,6 @@ in the real world.
 
 =item * Make a blogpost
 
-=item * Make git aliases for .gitconfig
-
 =back
 
 =cut
@@ -77,7 +86,7 @@ use File::Spec ();
 
 use constant DEBUG => $ENV{GIT_SHIP_DEBUG} || 0;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 my %DATA;
 
@@ -377,6 +386,7 @@ is to make a new tag and push it to "origin".
 sub ship {
   my $self = shift;
 
+  $self->abort("Cannot ship without a version number") unless $self->next_version;
   $self->system(qw( git tag ) => $self->next_version);
   $self->system(qw( git push --tags origin ));
 }
